@@ -1,13 +1,28 @@
 import json
+import os
 
+import tornado
 from notebook.base.handlers import IPythonHandler
 from notebook.utils import url_path_join
 
-import tornado
-from jupyter_server.serverapp import ServerApp
 
+class AppHandler(IPythonHandler):
+  """Thin wrapper around the IPython handler which injects common properties."""
+  @property
+  def config(self):
+      return self.settings["sn_config"]
 
-class AtlasGatewayEndpointHandler(IPythonHandler):
+class ConfigurationEndpointHandler(AppHandler):
+  """
+  Route handler for the /skillsnetwork-authoring-extension/config endpoint.
+
+  A single endpoint that returns the Atlas base URL.
+  """
+  def get(self) -> None:
+    print('test', type(self.config))
+    self.finish({"ATLAS_BASE_URL": self.config.atlas_base_url})
+
+class AtlasGatewayEndpointHandler(AppHandler):
   """Route handler for the /skillsnetwork-authoring-extension/gateway endpoint.
 
   This endpoint is a GET request that takes in a token URL parameter,
@@ -28,17 +43,20 @@ class AtlasGatewayEndpointHandler(IPythonHandler):
       self.redirect('/')
 
 
-def setup_handlers(web_app: ServerApp, url_path: str) -> None:
+def setup_handlers(web_app, url_path: str) -> None:
   """Setup handlers in the jupyter server web app.
 
   Args:
-    - web_app: Jupyter server app instance to add handlers to.
+    - web_app: Jupyter server web application instance to add handlers to.
     - url_path: Root url path for handlers.
   """
   host_pattern = ".*$"
   base_url = web_app.settings["base_url"]
 
   # Prepend the base_url so that it works in a JupyterHub setting
-  route_pattern = url_path_join(base_url, url_path, "gateway")
-  handlers = [(route_pattern, AtlasGatewayEndpointHandler)]
+  handler_url_path = url_path_join(base_url, url_path)
+  handlers = [
+    (url_path_join(handler_url_path, "gateway"), AtlasGatewayEndpointHandler),
+    (url_path_join(handler_url_path, "config"), ConfigurationEndpointHandler)
+  ]
   web_app.add_handlers(host_pattern, handlers)
